.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

xcsv: read/write CSV files
==========================

Defined in ``xtensor/xcsv.hpp``

.. doxygenfunction:: xt::load_csv
   :project: xtensor

.. doxygenfunction:: xt::dump_csv
   :project: xtensor
